var a00362 =
[
    [ "com::sun::star::uno::WeakReferenceHelper", "a01954.html", "a01954" ],
    [ "com::sun::star::uno::WeakReference&lt; interface_type &gt;", "a01958.html", "a01958" ]
];